@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <Qt3DRender/qraycaster.h>
 #include <Qt3DRender/qabstractfunctor.h>
 #include <Qt3DRender/qdepthtest.h>
@@ -149,6 +149,7 @@
 #include <Qt3DRender/qclearbuffers.h>
 #include <Qt3DRender/qscissortest.h>
 #include <Qt3DRender/qmaterial.h>
+#include <Qt3DRender/qrendercapabilities.h>
 #include <Qt3DRender/qlayer.h>
 #include <Qt3DRender/qcameralens.h>
 #include <Qt3DRender/qgraphicsapifilter.h>
@@ -285,74 +286,77 @@ enum : int {
     SBK_QT3DRENDER_QRAYCASTERHIT_HITTYPE_IDX                 = 108,
     SBK_QT3DRENDER_QRENDERASPECT_IDX                         = 109,
     SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX              = 110,
-    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 111,
-    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 112,
-    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 113,
-    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 114,
-    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 115,
-    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 116,
-    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 117,
-    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 118,
-    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 119,
-    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 120,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 121,
-    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 122,
-    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 123,
-    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 124,
-    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 126,
-    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 125,
-    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 127,
-    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 128,
-    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 129,
-    SBK_QT3DRENDER_QSETFENCE_IDX                             = 130,
-    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 131,
-    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 132,
-    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 133,
-    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 134,
-    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 135,
-    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 136,
-    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 137,
-    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 138,
-    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 139,
-    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 140,
-    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 141,
-    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 142,
-    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 143,
-    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 144,
-    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 145,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 146,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 147,
-    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 148,
-    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 149,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 150,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 151,
-    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 152,
-    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 153,
-    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 154,
-    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 155,
-    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 156,
-    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 157,
-    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 158,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 159,
-    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 160,
-    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 161,
-    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 162,
-    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 163,
-    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 164,
-    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 165,
-    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 166,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 167,
-    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 168,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 169,
-    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 170,
-    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 171,
-    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 172,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 173,
-    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 174,
-    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 175,
-    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 176,
-    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 177,
-    SBK_Qt3DRender_IDX_COUNT                                 = 178
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX                   = 111,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX               = 112,
+    SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX           = 113,
+    SBK_QT3DRENDER_QRENDERCAPTURE_IDX                        = 114,
+    SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX                   = 115,
+    SBK_QT3DRENDER_QRENDERPASS_IDX                           = 116,
+    SBK_QT3DRENDER_QRENDERPASSFILTER_IDX                     = 117,
+    SBK_QT3DRENDER_QRENDERSETTINGS_IDX                       = 118,
+    SBK_QT3DRENDER_QRENDERSETTINGS_RENDERPOLICY_IDX          = 119,
+    SBK_QT3DRENDER_QRENDERSTATE_IDX                          = 120,
+    SBK_QT3DRENDER_QRENDERSTATESET_IDX                       = 121,
+    SBK_QT3DRENDER_QRENDERSURFACESELECTOR_IDX                = 122,
+    SBK_QT3DRENDER_QRENDERTARGET_IDX                         = 123,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_IDX                   = 124,
+    SBK_QT3DRENDER_QRENDERTARGETOUTPUT_ATTACHMENTPOINT_IDX   = 125,
+    SBK_QT3DRENDER_QRENDERTARGETSELECTOR_IDX                 = 126,
+    SBK_QT3DRENDER_QSCENELOADER_IDX                          = 127,
+    SBK_QT3DRENDER_QSCENELOADER_STATUS_IDX                   = 129,
+    SBK_QT3DRENDER_QSCENELOADER_COMPONENTTYPE_IDX            = 128,
+    SBK_QT3DRENDER_QSCISSORTEST_IDX                          = 130,
+    SBK_QT3DRENDER_QSCREENRAYCASTER_IDX                      = 131,
+    SBK_QT3DRENDER_QSEAMLESSCUBEMAP_IDX                      = 132,
+    SBK_QT3DRENDER_QSETFENCE_IDX                             = 133,
+    SBK_QT3DRENDER_QSETFENCE_HANDLETYPE_IDX                  = 134,
+    SBK_QT3DRENDER_QSHADERDATA_IDX                           = 135,
+    SBK_QT3DRENDER_QSHADERIMAGE_IDX                          = 136,
+    SBK_QT3DRENDER_QSHADERIMAGE_ACCESS_IDX                   = 137,
+    SBK_QT3DRENDER_QSHADERIMAGE_IMAGEFORMAT_IDX              = 138,
+    SBK_QT3DRENDER_QSHADERPROGRAM_IDX                        = 139,
+    SBK_QT3DRENDER_QSHADERPROGRAM_SHADERTYPE_IDX             = 140,
+    SBK_QT3DRENDER_QSHADERPROGRAM_STATUS_IDX                 = 141,
+    SBK_QT3DRENDER_QSHADERPROGRAMBUILDER_IDX                 = 142,
+    SBK_QT3DRENDER_QSHAREDGLTEXTURE_IDX                      = 143,
+    SBK_QT3DRENDER_QSORTPOLICY_IDX                           = 144,
+    SBK_QT3DRENDER_QSORTPOLICY_SORTTYPE_IDX                  = 145,
+    SBK_QT3DRENDER_QSPOTLIGHT_IDX                            = 146,
+    SBK_QT3DRENDER_QSTENCILMASK_IDX                          = 147,
+    SBK_QT3DRENDER_QSTENCILOPERATION_IDX                     = 148,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_IDX            = 149,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_FACEMODE_IDX   = 150,
+    SBK_QT3DRENDER_QSTENCILOPERATIONARGUMENTS_OPERATION_IDX  = 151,
+    SBK_QT3DRENDER_QSTENCILTEST_IDX                          = 152,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_IDX                 = 153,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFACEMODE_IDX = 154,
+    SBK_QT3DRENDER_QSTENCILTESTARGUMENTS_STENCILFUNCTION_IDX = 155,
+    SBK_QT3DRENDER_QTECHNIQUE_IDX                            = 156,
+    SBK_QT3DRENDER_QTECHNIQUEFILTER_IDX                      = 157,
+    SBK_QT3DRENDER_QTEXTURE1D_IDX                            = 158,
+    SBK_QT3DRENDER_QTEXTURE1DARRAY_IDX                       = 159,
+    SBK_QT3DRENDER_QTEXTURE2D_IDX                            = 160,
+    SBK_QT3DRENDER_QTEXTURE2DARRAY_IDX                       = 161,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLE_IDX                 = 162,
+    SBK_QT3DRENDER_QTEXTURE2DMULTISAMPLEARRAY_IDX            = 163,
+    SBK_QT3DRENDER_QTEXTURE3D_IDX                            = 164,
+    SBK_QT3DRENDER_QTEXTUREBUFFER_IDX                        = 165,
+    SBK_QT3DRENDER_QTEXTURECUBEMAP_IDX                       = 166,
+    SBK_QT3DRENDER_QTEXTURECUBEMAPARRAY_IDX                  = 167,
+    SBK_QT3DRENDER_QTEXTUREDATA_IDX                          = 168,
+    SBK_QT3DRENDER_QTEXTUREGENERATOR_IDX                     = 169,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_IDX                         = 170,
+    SBK_QT3DRENDER_QTEXTUREIMAGE_STATUS_IDX                  = 171,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATA_IDX                     = 172,
+    SBK_QT3DRENDER_QTEXTUREIMAGEDATAGENERATOR_IDX            = 173,
+    SBK_QT3DRENDER_QTEXTURELOADER_IDX                        = 174,
+    SBK_QT3DRENDER_QTEXTURERECTANGLE_IDX                     = 175,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_IDX                      = 176,
+    SBK_QT3DRENDER_QTEXTUREWRAPMODE_WRAPMODE_IDX             = 177,
+    SBK_QT3DRENDER_QVIEWPORT_IDX                             = 178,
+    SBK_QT3DRENDER_QWAITFENCE_IDX                            = 179,
+    SBK_QT3DRENDER_QWAITFENCE_HANDLETYPE_IDX                 = 180,
+    SBK_Qt3DRender_IDX_COUNT                                 = 181
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_Qt3DRenderTypes;
@@ -365,17 +369,17 @@ extern SbkConverter **SbkPySide2_Qt3DRenderTypeConverters;
 
 // Converter indices
 enum : int {
-    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 0, // QVector<Qt3DCore::QNode* >
-    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 1, // const QList<QObject* > &
-    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 2, // QList<QByteArray >
-    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QENTITYPTR_IDX           = 3, // QVector<Qt3DCore::QEntity* >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QRAYCASTERHIT_IDX      = 4, // QVector<Qt3DRender::QRayCasterHit >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QLAYERPTR_IDX          = 5, // QVector<Qt3DRender::QLayer* >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 6, // QVector<Qt3DRender::QAbstractTextureImage* >
-    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 7, // QVector<Qt3DCore::QComponent* >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 8, // QVector<Qt3DRender::QParameter* >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QTECHNIQUEPTR_IDX      = 9, // QVector<Qt3DRender::QTechnique* >
-    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 10, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QENTITYPTR_IDX           = 0, // QVector<Qt3DCore::QEntity* >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QRAYCASTERHIT_IDX      = 1, // QVector<Qt3DRender::QRayCasterHit >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QLAYERPTR_IDX          = 2, // QVector<Qt3DRender::QLayer* >
+    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QNODEPTR_IDX             = 3, // QVector<Qt3DCore::QNode* >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QABSTRACTTEXTUREIMAGEPTR_IDX = 4, // QVector<Qt3DRender::QAbstractTextureImage* >
+    SBK_QT3DRENDER_QVECTOR_QT3DCORE_QCOMPONENTPTR_IDX        = 5, // QVector<Qt3DCore::QComponent* >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QPARAMETERPTR_IDX      = 6, // QVector<Qt3DRender::QParameter* >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QTECHNIQUEPTR_IDX      = 7, // QVector<Qt3DRender::QTechnique* >
+    SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QATTRIBUTEPTR_IDX      = 8, // QVector<Qt3DRender::QAttribute* >
+    SBK_QT3DRENDER_QLIST_QOBJECTPTR_IDX                      = 9, // const QList<QObject* > &
+    SBK_QT3DRENDER_QLIST_QBYTEARRAY_IDX                      = 10, // QList<QByteArray >
     SBK_QT3DRENDER_QVECTOR_QREAL_IDX                         = 11, // const QVector<qreal > &
     SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QFILTERKEYPTR_IDX      = 12, // QVector<Qt3DRender::QFilterKey* >
     SBK_QT3DRENDER_QVECTOR_QT3DRENDER_QRENDERSTATEPTR_IDX    = 13, // QVector<Qt3DRender::QRenderState* >
@@ -507,6 +511,9 @@ template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRayCasterHit::HitType >(
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRayCasterHit >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRAYCASTERHIT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderAspect::RenderType >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERASPECT_RENDERTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderAspect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERASPECT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderCapabilities::API >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERCAPABILITIES_API_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderCapabilities::Profile >() { return SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERCAPABILITIES_PROFILE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderCapabilities >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERCAPABILITIES_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderCapture >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERCAPTURE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderCaptureReply >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERCAPTUREREPLY_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DRender::QRenderPass >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DRenderTypes[SBK_QT3DRENDER_QRENDERPASS_IDX]); }
