@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtCharts/qbarseries.h>
 #include <QtCharts/qxyseries.h>
 #include <QtCharts/qarealegendmarker.h>
@@ -218,16 +218,15 @@ enum : int {
     SBK_QTCHARTS_QLIST_QACTIONPTR_IDX                        = 7, // QList<QAction* >
     SBK_QTCHARTS_QLIST_QTCHARTS_QABSTRACTSERIESPTR_IDX       = 8, // QList<QtCharts::QAbstractSeries* >
     SBK_QTCHARTS_QLIST_QGRAPHICSITEMPTR_IDX                  = 9, // QList<QGraphicsItem* >
-    SBK_QTCHARTS_QLIST_QWIDGETPTR_IDX                        = 10, // QList<QWidget* >
-    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 11, // const QList<QRectF > &
-    SBK_QTCHARTS_QLIST_QTCHARTS_QLEGENDMARKERPTR_IDX         = 12, // QList<QtCharts::QLegendMarker* >
-    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 13, // const QList<QPointF > &
-    SBK_QTCHARTS_QVECTOR_QPOINTF_IDX                         = 14, // QVector<QPointF >
-    SBK_QTCHARTS_QLIST_QTCHARTS_QPIESLICEPTR_IDX             = 15, // QList<QtCharts::QPieSlice* >
-    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 16, // QList<QVariant >
-    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 17, // QList<QString >
-    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 18, // QMap<QString,QVariant >
-    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 19
+    SBK_QTCHARTS_QLIST_QRECTF_IDX                            = 10, // const QList<QRectF > &
+    SBK_QTCHARTS_QLIST_QTCHARTS_QLEGENDMARKERPTR_IDX         = 11, // QList<QtCharts::QLegendMarker* >
+    SBK_QTCHARTS_QLIST_QPOINTF_IDX                           = 12, // const QList<QPointF > &
+    SBK_QTCHARTS_QVECTOR_QPOINTF_IDX                         = 13, // QVector<QPointF >
+    SBK_QTCHARTS_QLIST_QTCHARTS_QPIESLICEPTR_IDX             = 14, // QList<QtCharts::QPieSlice* >
+    SBK_QTCHARTS_QLIST_QVARIANT_IDX                          = 15, // QList<QVariant >
+    SBK_QTCHARTS_QLIST_QSTRING_IDX                           = 16, // QList<QString >
+    SBK_QTCHARTS_QMAP_QSTRING_QVARIANT_IDX                   = 17, // QMap<QString,QVariant >
+    SBK_QtCharts_CONVERTERS_IDX_COUNT                        = 18
 };
 // Macros for type check
 
@@ -235,6 +234,8 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QtCharts::QAbstractAxis::AxisType >() { return SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QABSTRACTAXIS_AXISTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QtCharts::QAbstractAxis >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QABSTRACTAXIS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QtCharts::QAbstractBarSeries::LabelsPosition >() { return SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QABSTRACTBARSERIES_LABELSPOSITION_IDX]; }
@@ -304,6 +305,7 @@ template<> inline PyTypeObject *SbkType< ::QtCharts::QValueAxis >() { return rei
 template<> inline PyTypeObject *SbkType< ::QtCharts::QXYLegendMarker >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QXYLEGENDMARKER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QtCharts::QXYModelMapper >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QXYMODELMAPPER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QtCharts::QXYSeries >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtChartsTypes[SBK_QTCHARTS_QXYSERIES_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
