@@ -58,9 +58,9 @@
 #include <QtQuick/qsgtexture.h>
 #include <QtQuick/qquickwindow.h>
 #include <QtQuick/qsgtextureprovider.h>
-#include <QtCore/qsharedpointer.h>
 #include <QtQuick/qsgabstractrenderer.h>
 #include <QtQuick/qquickview.h>
+#include <qsharedpointer.h>
 #include <QtQuick/qquickpainteditem.h>
 #include <QtQuick/qsgsimplerectnode.h>
 #include <QtQuick/qquickitemgrabresult.h>
@@ -164,6 +164,7 @@ enum : int {
     SBK_QSGTEXTUREPROVIDER_IDX                               = 68,
     SBK_QSGTRANSFORMNODE_IDX                                 = 69,
     SBK_QSHAREDPOINTER_QQUICKITEMGRABRESULT_IDX              = 71, // QSharedPointer<QQuickItemGrabResult >
+    SBK_QSHAREDPOINTER_CONSTQQUICKITEMGRABRESULT_IDX         = 71, //   (const)
     SBK_QtQuick_IDX_COUNT                                    = 72
 };
 // This variable stores all Python types exported by this module.
@@ -178,9 +179,9 @@ extern SbkConverter **SbkPySide2_QtQuickTypeConverters;
 // Converter indices
 enum : int {
     SBK_QTQUICK_QLIST_QQUICKITEMPTR_IDX                      = 0, // QList<QQuickItem* >
-    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 1, // const QList<QObject* > &
-    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 2, // QList<QByteArray >
-    SBK_QTQUICK_QVECTOR_INT_IDX                              = 3, // const QVector<int > &
+    SBK_QTQUICK_QVECTOR_INT_IDX                              = 1, // const QVector<int > &
+    SBK_QTQUICK_QLIST_QOBJECTPTR_IDX                         = 2, // const QList<QObject* > &
+    SBK_QTQUICK_QLIST_QBYTEARRAY_IDX                         = 3, // QList<QByteArray >
     SBK_QTQUICK_QLIST_QQMLERROR_IDX                          = 4, // QList<QQmlError >
     SBK_QTQUICK_QMAP_QSTRING_QVARIANT_IDX                    = 5, // const QMap<QString,QVariant > &
     SBK_QTQUICK_QLIST_QVARIANT_IDX                           = 6, // QList<QVariant >
